diff --git a/cmd/geth/config.go b/cmd/geth/config.go
index b450dd9c8bd4c2286020e886d8c06dc03774e67c..71e8355348c1f361df0b542f39eba41bbedabbd8 100644
--- a/cmd/geth/config.go
+++ b/cmd/geth/config.go
@@ -99,8 +99,8 @@ func defaultNodeConfig() node.Config {
 	cfg := node.DefaultConfig
 	cfg.Name = clientIdentifier
 	cfg.Version = params.VersionWithCommit(gitCommit, gitDate)
-	cfg.HTTPModules = append(cfg.HTTPModules, "eth", "shh")
-	cfg.WSModules = append(cfg.WSModules, "eth", "shh")
+	cfg.HTTPModules = append(cfg.HTTPModules, "eth")
+	cfg.WSModules = append(cfg.WSModules, "eth")
 	cfg.IPCPath = "geth.ipc"
 	return cfg
 }
diff --git a/rpc/endpoints.go b/rpc/endpoints.go
index 8ca6d4eb0c6d5f3b565c8dba16644531dadf1b0d..2cf51aedfcc703d7a6ccc87ab0d309d567a2f09a 100644
--- a/rpc/endpoints.go
+++ b/rpc/endpoints.go
@@ -17,13 +17,39 @@
 package rpc
 
 import (
+	"fmt"
 	"net"
 
 	"github.com/ethereum/go-ethereum/log"
 )
 
-// StartHTTPEndpoint starts the HTTP RPC endpoint, configured with cors/vhosts/modules
+// checkModuleAvailability check that all names given in modules are actually
+// available API services.
+func checkModuleAvailability(modules []string, apis []API) error {
+	available := make(map[string]struct{})
+	var availableNames string
+	for i, api := range apis {
+		if _, ok := available[api.Namespace]; !ok {
+			available[api.Namespace] = struct{}{}
+			if i > 0 {
+				availableNames += ", "
+			}
+			availableNames += api.Namespace
+		}
+	}
+	for _, name := range modules {
+		if _, ok := available[name]; !ok {
+			return fmt.Errorf("invalid API %q in whitelist (available: %s)", name, availableNames)
+		}
+	}
+	return nil
+}
+
+// StartHTTPEndpoint starts the HTTP RPC endpoint, configured with cors/vhosts/modules.
 func StartHTTPEndpoint(endpoint string, apis []API, modules []string, cors []string, vhosts []string, timeouts HTTPTimeouts) (net.Listener, *Server, error) {
+	if err := checkModuleAvailability(modules, apis); err != nil {
+		return nil, nil, err
+	}
 	// Generate the whitelist based on the allowed modules
 	whitelist := make(map[string]bool)
 	for _, module := range modules {
@@ -51,9 +77,11 @@ func StartHTTPEndpoint(endpoint string, apis []API, modules []string, cors []str
 	return listener, handler, err
 }
 
-// StartWSEndpoint starts a websocket endpoint
+// StartWSEndpoint starts a websocket endpoint.
 func StartWSEndpoint(endpoint string, apis []API, modules []string, wsOrigins []string, exposeAll bool) (net.Listener, *Server, error) {
-
+	if err := checkModuleAvailability(modules, apis); err != nil {
+		return nil, nil, err
+	}
 	// Generate the whitelist based on the allowed modules
 	whitelist := make(map[string]bool)
 	for _, module := range modules {